# Foundry

<p align="center">
<a href="https://github.com/TheJoeSmo/Foundry/actions"><img alt="Actions Status" src="https://github.com/TheJoeSmo/Foundry/actions/workflows/tests.yml/badge.svg"></a>
<a href="https://github.com/TheJoeSmo/Foundry/actions"><img alt="Actions Status" src="https://github.com/TheJoeSmo/Foundry/actions/workflows/github_pages.yml/badge.svg"></a>
<a href="https://github.com/TheJoeSmo/Foundry/block/main/LICENSE.md"><img alt="License GPL3" src="https://img.shields.io/badge/License-GPLv3-blue.svg"></a>
<a href="https://pypi.org/project/foundry-smb3/"><img alt="PyPI" src="https://img.shields.io/pypi/v/foundry-smb3"></a>
<a href="https://pepy.tech/project/black"><img alt="Downloads" src="https://pepy.tech/badge/foundry-smb3"></a>
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

Foundry is the leading editor for SMB3.
- Website: https://thejoesmo.github.io/Foundry/
- Discord: https://discord.gg/pm87gm7
- Documentation: https://thejoesmo.github.io/Foundry/
- Manual: https://github.com/TheJoeSmo/Foundry/blob/master/MANUAL.md
- Source Code: https://github.com/TheJoeSmo/Foundry
- Bug Reporting: https://github.com/TheJoeSmo/Foundry/issues

It provides:
- A powerful level editor

Testing:
Foundry uses `Poetry` as its package manager.  WIP.

Call for Contributions
----------------------
Foundry is a community driven initiative that relies on your help and expertise.

Small improvements or fixes are critical to this repository's success.  Issues labeled `good first issue` are a great place to start.  For larger contributions WIP.

You do not need to be literate with programming to aid Foundry on its journey.  We also need help with:
- Developing tutorials
- Creating graphics for our brand and promotional material
- Translation
- Outreach and onboarding new contributors
- Reviewing issues and suggestions

If you are undecided on where to start, we encourage you to reach out.  You can ask on our Discord or privately through email.

If you are new to open source projects and want to be caught up to speed, we recommend [this guide](https://opensource.guide/how-to-contribute/)